@@ -135,14 +135,6 @@ genindex.htmlの作り方
     {%- endif %}
     {% endmacro %}
 
-履歴
-====
-| 2021-09-26 0.17 同名関数の表示方法. see/seealsoの表示順. PyPI準備. 他.
-| 2021-09-25 1.2 KanaIndexerクラス. エントリーデータの優先順を変更. 他.
-| 2021-09-24 1.1 仮名がある時は「あかさたなは…わ」の項目に振り分ける. 第一用語の重複チェク.
-| 2021-09-23 1.0 1.0として再公開.
-| 2021-09-13 0.1 Qiitaで公開.
-
 開発者向け
 ==========
 変数名
@@ -234,7 +226,7 @@ latexの関連情報
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.18.1.1'
+__version__ = '0.19.0.1'
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re
@@ -730,23 +722,46 @@ class KanaIndexer(object):
         self._max_len_sub  = 0 #max length of subterm
         self._term_to_classifier = {}
         self._term_to_kana = {} #Dict{term: List[emphasis, kana]}
+        self._homonymous_functions = {} #Dict{func name: number of func}
 
-        #インデクシング
-        self._recreate_entries(entries.items()) #1.ソート用文字列の下拵え（group by含む）
-        self._create_sortkey_and_sort()         #2.ソート用文字列の作成とソート
-        return self._create_genindex_entries(group_entries, _fixre) #3.ソート済みを前提にデータの作成
+        #インデクシング（概要）
+        #1. self._prepare_sortkey_and_make_entries()
+        #   - ソート用文字列の下拵え（group by含む）
+        #   - 2で作るsortkeyを収める場所を確保.
+        #   - 3で必要な要素をタプルで用意する.
+        #   - 2,3で必要な、全データを確認して分かることを調べておく.
+        #2. self._make_sortkey_and_sort()
+        #   - ソート用文字列の作成とソート.
+        #   1. ソート用の各データは最大長に合わせて半角空白で埋めて固定長にする.
+        #   2. 固定長になった各データを結合して一つの固定長文字列を作る.
+        #   3. この固定長でソートする.
+        #3. self._create_genindex_entries()
+        #   - ソート済みを前提にデータの作成
+        #   - データ構造が複雑なので、混乱しないように意図の分かる変数名を逐一当てる.
+        self._prepare_sortkey_and_make_entries(entries.items(), group_entries, _fixre)
+        self._make_sortkey_and_sort()
+        return self._create_genindex_entries(group_entries, _fixre)
 
-    def _recreate_entries(self, entries_on_each_file):
+    def _prepare_sortkey_and_make_entries(self, entries_on_each_file, group_entries, _fixre):
         def add_entry(term, subterm, emphasis, link=True):
             if index_key:
                 _clf = index_key
 
                 if not term in self._term_to_classifier:
                     self._term_to_classifier[term] = index_key
-                #indexでclassifierの指定はできないが、念の為早い者勝ちにしておく.
+                #indexでclassifierの指定はできないが、念の為"早い者勝ち"にしておく.
             else:
                 _clf = _get_classifier_by_first_char(term, self.config)
 
+            #homonymous functions
+            if group_entries:
+                m = _fixre.match(term)
+                if m:
+                    try:
+                        self._homonymous_functions[m.group(1)] += 1
+                    except KeyError as err:
+                        self._homonymous_functions[m.group(1)] = 1
+
             #ソート処理のために文字幅が揃う一文字に変換
             _em = _emphasis2char[emphasis] 
 
@@ -807,7 +822,7 @@ class KanaIndexer(object):
                 except ValueError as err:
                     logger.warning(str(err), location=fn)
 
-    def _create_sortkey_and_sort(self):
+    def _make_sortkey_and_sort(self):
         for entry in self._now_entries:
             clf, tm, sub, em, link, fn, tid, ikey = entry[1]
 
@@ -862,8 +877,9 @@ class KanaIndexer(object):
             #     (in module bar) 
             if group_entries:
                 m = _fixre.match(tm)
-                if m:
-                    if sub: raise ValueError(f'{self.__class__.__name__}: subterm is not null: {sub}')
+                if m and self._homonymous_functions[m.group(1)] > 1:
+                    #状況的にsubtermは空のはず.
+                    assert not sub, f'{self.__class__.__name__}: subterm is not null: {sub}'
                     tm = m.group(1)
                     sub = m.group(2)
             #subの情報が消えるが、このケースに該当する場合はsubにはデータがないはず.
